@@ -1,10 +1,16 @@
 montecarlo <-
 function(obj,alpha=0.01,nr=100) {
+call<-match.call()
+if (class(obj)!="lordif") stop(paste(deparse(substitute(obj)),"must be of class lordif"))
+if (alpha<0 | alpha>1) stop("alpha must be a fraction between 0 and 1")
+if (nr<100) warning("number of replications is less than 100")
+if (nr<=0) stop("number of replications is not a positive integer")
 options<-obj$options
 ipar<-obj$ipar
 group<-obj$group
 ncat<-obj$ncat
-theta<-obj$calib.sparse$theta
+if (sum(obj$flag)>0) theta<-obj$calib.sparse$theta
+else theta<-obj$calib$theta
 selection<-obj$selection
 nobs<-length(theta)
 ni<-nrow(ipar)
@@ -22,6 +28,7 @@ pseudo12.McFadden<-matrix(NA,nr,ni);rownames(pseudo12.McFadden)<-paste("Rep",1:n
 pseudo13.McFadden<-matrix(NA,nr,ni);rownames(pseudo13.McFadden)<-paste("Rep",1:nr,sep="");colnames(pseudo13.McFadden)<-paste("I",selection,sep="")
 pseudo23.McFadden<-matrix(NA,nr,ni);rownames(pseudo23.McFadden)<-paste("Rep",1:nr,sep="");colnames(pseudo23.McFadden)<-paste("I",selection,sep="")
 beta12<-matrix(NA,nr,ni);rownames(beta12)<-paste("Rep",1:nr,sep="");colnames(beta12)<-paste("I",selection,sep="")
+cat(paste("Start time:",date(),"\n\n"))
 for (r in 1:nr) {
 random<-matrix(runif(nobs*ni),nobs,ni)
 resp<-data.frame(matrix(NA,nobs,ni))
@@ -45,8 +52,9 @@ pseudo12.McFadden[r,]<-out$stats$pseudo12.McFadden
 pseudo13.McFadden[r,]<-out$stats$pseudo13.McFadden
 pseudo23.McFadden[r,]<-out$stats$pseudo23.McFadden
 beta12[r,]<-out$stats$beta
-cat(paste("Replication: ",r,"\n",sep=""))
+cat(paste(" Replication: ",r,"\n",sep=""))
 }
+cat(paste("\nEnd time:",date(),"\n"))
 stat<-c("chi12","chi13","chi23","pseudo12.CoxSnell","pseudo13.CoxSnell","pseudo23.CoxSnell","pseudo12.Nagelkerke","pseudo13.Nagelkerke","pseudo23.Nagelkerke","pseudo12.McFadden","pseudo13.McFadden","pseudo23.McFadden","beta12")
 cutoff<-matrix(NA,ni,length(stat))
 for (i in 1:ni) {
@@ -66,10 +74,12 @@ cutoff[i,13]<-getcutoff(beta12[,i],alpha,T)
 }
 colnames(cutoff)<-stat
 rownames(cutoff)<-paste("I",selection,sep="")
-return(list(chi12=chi12,chi13=chi13,chi23=chi23,
+out<-list(call=call,chi12=chi12,chi13=chi13,chi23=chi23,
 pseudo12.CoxSnell=pseudo12.CoxSnell,pseudo13.CoxSnell=pseudo13.CoxSnell,pseudo23.CoxSnell=pseudo23.CoxSnell,
 pseudo12.Nagelkerke=pseudo12.Nagelkerke,pseudo13.Nagelkerke=pseudo13.Nagelkerke,pseudo23.Nagelkerke=pseudo23.Nagelkerke,
 pseudo12.McFadden=pseudo12.McFadden,pseudo13.McFadden=pseudo13.McFadden,pseudo23.McFadden=pseudo23.McFadden,
-beta12=beta12,alpha=alpha,nr=nr,cutoff=data.frame(cutoff)))
+beta12=beta12,alpha=alpha,nr=nr,cutoff=data.frame(cutoff))
+class(out)<-"lordif.MC"
+return(out)
 }
 
